@@ -136,6 +136,10 @@ class MacroProgram(ElementProgram):
     # attributes, e.g. "data-tal-content" instead of "tal:content".
     enable_data_attributes = False
 
+    # If set, XML namespaces are restricted to the list of those
+    # defined and used by the page template language.
+    restricted_namespace = True
+
     def __init__(self, *args, **kwargs):
         # Internal array for switch statements
         self._switches = []
@@ -159,6 +163,7 @@ class MacroProgram(ElementProgram):
             'implicit_i18n_attributes',
             'trim_attribute_space',
             'enable_data_attributes',
+            'restricted_namespace',
             )
 
         super(MacroProgram, self).__init__(*args, **kwargs)
@@ -185,7 +190,7 @@ class MacroProgram(ElementProgram):
             convert_data_attributes(ns, attrs, start['ns_map'])
 
         for (prefix, attr), encoded in tuple(ns.items()):
-            if prefix == TAL:
+            if prefix == TAL or prefix == METAL:
                 ns[prefix, attr] = decode_htmlentities(encoded)
 
         # Validate namespace attributes
@@ -770,7 +775,7 @@ class MacroProgram(ElementProgram):
             # interpolation expressions, apply interpolation
             # substitution to the text
             if expr is None and text is not None and '${' in text:
-                expr = nodes.Substitution(text, char_escape, None)
+                expr = nodes.Substitution(text, char_escape)
                 translation = implicit_i18n and msgid is missing
                 value = nodes.Interpolation(expr, True, translation)
                 default_marker = self.default_marker
@@ -779,7 +784,7 @@ class MacroProgram(ElementProgram):
             # dynamic (computed).
             elif expr is not None:
                 if name is None:
-                    expression = nodes.Value(expr)
+                    expression = nodes.Value(decode_htmlentities(expr))
                     value = nodes.DictAttributes(
                         expression, ('&', '<', '>', '"'), '"',
                         set(filter(None, names[i:]))
@@ -795,7 +800,11 @@ class MacroProgram(ElementProgram):
                     else:
                         default = None
 
-                    value = nodes.Substitution(expr, char_escape, default)
+                    value = nodes.Substitution(
+                        decode_htmlentities(expr),
+                        char_escape,
+                        default
+                    )
 
             # Otherwise, it's a static attribute. We don't include it
             # here if there's one or more "computed" attributes
